==> ipless-8.x-2.0.tar.gz: ipless/src/Form/IpLessSettingForm.php <==
<?php

namespace Drupal\ipless\Form;

use \Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * IpLessSettingForm
 */
class IpLessSettingForm {

  use StringTranslationTrait;

  /**
   * Form Alter
   */
  public function formAlter_system_performance_settings(&$form, FormStateInterface $form_state) {
    $config = \Drupal::config('system.performance');

    $form['bandwidth_optimization']['ipless'] = [
      '#type'  => 'fieldset',
      '#title' => $this->t('Less CSS'),
      '#tree'  => true
    ];

    $form['bandwidth_optimization']['ipless']['ipless_enabled'] = array(
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_enabled'),
      '#title'         => t('Less compilation enabled'),
    );

    $form['bandwidth_optimization']['ipless']['ipless_modedev'] = array(
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_modedev'),
      '#title'         => t('Less developper mode'),
      '#description'   => t('Compile Less file all the time.')
    );

    $form['bandwidth_optimization']['ipless']['ipless_sourcemap'] = array(
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_sourcemap'),
      '#title'         => t('Enable SourceMap'),
    );

    $form['#submit'][] = static::class . '::checkSettings';
  }

  /**
   * 
   * @param type $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   * @param type $form_id
   */
  public static function checkSettings(array &$form, FormStateInterface $form_state) {
    $ipless = $form_state->getValue('ipless');

    $config = \Drupal::service('config.factory')->getEditable('system.performance');
    foreach ($ipless as $key => $value)
      $config->set($key, $value);
    $config->save();
  }

}

==> ipless-8.x-2.1.tar.gz: ipless/src/Form/IpLessSettingForm.php <==
<?php

namespace Drupal\ipless\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * IpLessSettingForm.
 */
class IpLessSettingForm {

  use StringTranslationTrait;

  /**
   * Form Alter.
   */
  public function formAlter_system_performance_settings(&$form, FormStateInterface $form_state) {
    $config = \Drupal::config('system.performance');

    $form['bandwidth_optimization']['ipless'] = [
      '#type'  => 'fieldset',
      '#title' => $this->t('Less CSS'),
      '#tree'  => TRUE
    ];

    $form['bandwidth_optimization']['ipless']['ipless_enabled'] = [
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_enabled'),
      '#title'         => t('Less compilation enabled'),
      ];

    $form['bandwidth_optimization']['ipless']['ipless_modedev'] = [
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_modedev'),
      '#title'         => t('Less developper mode'),
      '#description'   => t('Compile Less file all the time.')
      ];

    $form['bandwidth_optimization']['ipless']['ipless_sourcemap'] = [
      '#type'          => 'checkbox',
      '#default_value' => $config->get('ipless_sourcemap'),
      '#title'         => t('Enable SourceMap'),
      ];

    $form['#submit'][] = static::class . '::checkSettings';
  }

  /**
   * Form Callback : Check settings.
   * @param array $form
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   */
  public static function checkSettings(array &$form, FormStateInterface $form_state) {
    $ipless = $form_state->getValue('ipless');

    $config = \Drupal::service('config.factory')->getEditable('system.performance');
    foreach ($ipless as $key => $value){
      $config->set($key, $value);
    }
    $config->save();
  }

}
